@@ -17,6 +17,7 @@ if TYPE_CHECKING:
         GeminiComputerTool,
         HudComputerTool,
         OpenAIComputerTool,
+        QwenComputerTool,
     )
 
 __all__ = [
@@ -29,6 +30,7 @@ __all__ = [
     "HudComputerTool",
     "OpenAIComputerTool",
     "PlaywrightTool",
+    "QwenComputerTool",
     "ResponseTool",
     "SubmitTool",
 ]
@@ -41,6 +43,7 @@ def __getattr__(name: str) -> Any:
         "HudComputerTool",
         "OpenAIComputerTool",
         "GeminiComputerTool",
+        "QwenComputerTool",
     ):
         from . import computer
 
